/*
  nokiaLCD.h - Library for providing a text based interface to the Nokia 5110 LCD screen
  Written by Rylee Isitt
  Parts of this Library are based on the example code provided by SparkFun, copyright 2011 Nathan Seidle
  SparkFun's code was used with permission (released into the public domain)
  I make no copyright claims to their original code
*/
#ifndef nokiaLCD_H
#define nokiaLCD_H

#include <Arduino.h>

// Configuration for the Nokia 5110 LCD
#define LCD_C     LOW
#define LCD_D     HIGH
#define LCD_X     84
#define LCD_Y     48
#define LCD_ROWS  6
#define LCD_COLS  12

class nokiaLCD {
  public:
    nokiaLCD(void);
    ~nokiaLCD(void);
    void begin(byte pinSCE, byte pinRESET, byte pinDC, byte pinSDIN, byte pinSCLK, byte pinLED);
    void updateText(void);
    void putText(String text, byte row, byte col, boolean invert = false, boolean custom = false);
    void clearText(void);
    void toggleBacklight(void);
    void setGlyphInvert(byte row, byte col, boolean invert);
    void setGlyphCustom(byte row, byte col, boolean custom);
  private:
    String curText[6];
    byte codes[LCD_ROWS][LCD_COLS];
    byte pinSCE;
    byte pinRESET;
    byte pinDC;
    byte pinSDIN;
    byte pinSCLK;
    byte pinLED;
    boolean backlightState;
    byte getGlyphByte(byte glyphID, byte glyphByteID, boolean useCustom = false);
    void gotoXY(int x, int y);
    void lcdWrite(byte dc, byte data);
};

#endif


